unit uChiffrierer;

interface

uses uCodierung;

type
  TChiffrierer = class
  private
    quelltext: string;
    geheimtext: string;
    schluessel: string;
    codierung: TCodierung;
  public
    constructor create;
    procedure setQuelltext(t: string);
    function getQuelltext: string;
    procedure setGeheimtext(t: string);
    function getGeheimtext: string;
    procedure setSchluessel(s: string);
    function getCode: string;
    procedure vorbereiten;
    procedure verschluesseln;
    procedure entschluesseln;
  end;

implementation

constructor TChiffrierer.create;
begin
  quelltext := '';
  geheimtext := '';
  codierung := TCodierung.create;
end;

procedure TChiffrierer.setQuelltext(t: string);
begin
  quelltext := t;
end;

function TChiffrierer.getQuelltext: string;
begin
  result := quelltext;
end;

procedure TChiffrierer.setGeheimtext(t: string);
begin
  geheimtext := t;
end;

procedure TChiffrierer.setSchluessel(s: string);
begin
  schluessel := s;
  codierung.setCode(schluessel);
end;

function TChiffrierer.getCode: string;
begin
  result := codierung.getCode;
end;

function TChiffrierer.getGeheimtext: string;
begin
  result := geheimtext;
end;

procedure TChiffrierer.vorbereiten;
  var c: char;
      i: integer;
      hilfstext: string;
begin
  hilfstext := '';
  for i := 1 to length(quelltext) do
  begin
    c := quelltext[i];
    case c of
      'A'..'Z': hilfstext := hilfstext + c;
      '0'..'9': hilfstext := hilfstext + c;
      'a'..'z': hilfstext := hilfstext + chr(ord(c)-32);
      '': hilfstext := hilfstext + 'SS';
      '': hilfstext := hilfstext + 'AE';
      '': hilfstext := hilfstext + 'OE';
      '': hilfstext := hilfstext + 'UE';
      '': hilfstext := hilfstext + 'AE';
      '': hilfstext := hilfstext + 'OE';
      '': hilfstext := hilfstext + 'UE';
    end;
  end;
  quelltext := hilfstext;
end;

procedure TChiffrierer.verschluesseln;
  var
    i: integer;
    klar, geheim: char;
begin
  geheimtext := '';
  for i := 1 to length(quelltext) do
  begin
    klar := quelltext[i];
    geheim := codierung.getGeheim(klar);
    geheimtext := geheimtext + geheim;
  end;
end;

procedure TChiffrierer.entschluesseln;
  var
    i: integer;
    klar, geheim: char;
begin
  quelltext := '';
  for i := 1 to length(geheimtext) do
  begin
    geheim := geheimtext[i];
    klar := codierung.getKlar(geheim);
    quelltext := quelltext + klar;
  end;
end;

end.
