unit uSpielmanager;

interface

uses uWuerfel, uKonto, uSpielbrett;

type
  TSpielmanager = class
  private
    zustand: integer;
    wuerfelA: TWuerfel;
    wuerfelB: TWuerfel;
    wuerfelC: TWuerfel;
    konto: TKonto;
    spielbrett: TSpielbrett;
  public
    constructor create;
    destructor destroy; override;
    procedure einsatzZahlen;
    procedure spielzahlSetzen(z: integer);
    procedure wuerfelWerfen;
    procedure gewinnVerbuchen;
    function getWuerfelA: integer;
    function getWuerfelB: integer;
    function getWuerfelC: integer;
    function getKonto: integer;
    function getZustand: integer;
  end;

implementation

constructor TSpielmanager.create;
begin
  zustand := 0;
  wuerfelA := TWuerfel.create;
  wuerfelB := TWuerfel.create;
  wuerfelC := TWuerfel.create;
  konto := TKonto.create(100);
  spielbrett := TSpielbrett.create;
end;

destructor TSpielmanager.destroy;
begin
  wuerfelA.free;
  wuerfelB.free;
  wuerfelC.free;
  konto.free;
  spielbrett.free;
end;

procedure TSpielmanager.einsatzZahlen;
begin
  if zustand = 0 then
  begin
    konto.abheben(1);
    zustand := 1;
  end;
end;

procedure TSpielmanager.spielzahlSetzen(z: integer);
begin
  if zustand = 1 then
  begin
    spielbrett.setzen(z);
    zustand := 1;
  end;
end;

procedure TSpielmanager.wuerfelWerfen;
begin
  if zustand = 1 then
  begin
    wuerfelA.werfen;
    wuerfelB.werfen;
    wuerfelC.werfen;
    zustand := 2;
  end;
end;

procedure TSpielmanager.gewinnVerbuchen;
  var richtige, zahl: integer;
begin
  if zustand = 2 then
  begin
    richtige := 0;
    zahl := spielbrett.getZahl;
    if zahl = wuerfelA.getAugen then inc(richtige);
    if zahl = wuerfelB.getAugen then inc(richtige);
    if zahl = wuerfelC.getAugen then inc(richtige);
    if richtige > 0 then konto.einzahlen(richtige+1);
    zustand := 0;
  end;
end;

function TSpielmanager.getWuerfelA: integer;
begin
  result := wuerfelA.getAugen;
end;

function TSpielmanager.getWuerfelB: integer;
begin
  result := wuerfelB.getAugen;
end;

function TSpielmanager.getWuerfelC: integer;
begin
  result := wuerfelC.getAugen;
end;

function TSpielmanager.getKonto: integer;
begin
  result := konto.getStand;
end;

function TSpielmanager.getZustand: integer;
begin
  result := zustand;
end;

end.
