unit uGUI;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls, uRoboter, uWelt;

type
  TGUI = class(TForm)
    IZeichnen: TImage;
    PSteuerung: TPanel;
    BInitialisieren: TButton;
    BLinks: TButton;
    BSchritt: TButton;
    BRechts: TButton;
    BMarkeSetzen: TButton;
    BMarkeLoeschen: TButton;
    BZiegelHinlegen: TButton;
    BZiegelAufheben: TButton;
    procedure BInitialisierenClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure BLinksClick(Sender: TObject);
    procedure BRechtsClick(Sender: TObject);
    procedure BSchrittClick(Sender: TObject);
    procedure BMarkeSetzenClick(Sender: TObject);
    procedure BZiegelAufhebenClick(Sender: TObject);
    procedure BMarkeLoeschenClick(Sender: TObject);
    procedure BZiegelHinlegenClick(Sender: TObject);

  private
    { Private-Deklarationen }
    roboter: TRoboter;
    welt: TWelt;
    procedure dreieckOsten(x1, y1, x2, y2: integer);
    procedure dreieckSueden(x1, y1, x2, y2: integer);
    procedure dreieckWesten(x1, y1, x2, y2: integer);
    procedure dreieckNorden(x1, y1, x2, y2: integer);
  public
    { Public-Deklarationen }
    procedure weltZeichnen;
    procedure roboterZeichnen;
  end;

var
  GUI: TGUI;

implementation

{$R *.DFM}

procedure TGUI.dreieckOsten(x1, y1, x2, y2: integer);
begin
  with IZeichnen.Canvas do
  begin
    Pen.Color := clBlack;
    Brush.Color := clBlack;
    Polygon([Point(x1, y1), Point(x2, (y1+y2) div 2), Point(x1, y2)]);
  end;
end;

procedure TGUI.dreieckSueden(x1, y1, x2, y2: integer);
begin
  with IZeichnen.Canvas do
  begin
    Pen.Color := clBlack;
    Brush.Color := clBlack;
    Polygon([Point(x1, y1), Point(x2, y1), Point((x1+x2) div 2, y2)]);
  end;
end;

procedure TGUI.dreieckWesten(x1, y1, x2, y2: integer);
begin
  with IZeichnen.Canvas do
  begin
    Pen.Color := clBlack;
    Brush.Color := clBlack;
    Polygon([Point(x2, y1), Point(x1, (y1+y2) div 2), Point(x2, y2)]);
  end;
end;

procedure TGUI.dreieckNorden(x1, y1, x2, y2: integer);
begin
  with IZeichnen.Canvas do
  begin
    Pen.Color := clBlack;
    Brush.Color := clBlack;
    Polygon([Point(x1, y2), Point(x2, y2), Point((x1+x2) div 2, y1)]);
  end;
end;

procedure TGUI.weltZeichnen;
  var i, j: integer;
begin
  with IZeichnen.Canvas do
    with welt do
    begin
      Pen.Color := clBlue;
      for i := 0 to 9 do
        for j := 0 to 9 do
        begin
          Brush.Color := clWhite;
          if getZiegel(i,j) > 0 then
            Brush.Color := clRed;
          if getMarke(i,j) then
            Brush.Color := clYellow;
          Rectangle(i*40, j*40, (i+1)*40, (j+1)*40);
          if getZiegel(i,j) > 0 then
            TextOut(i*40+15, j*40+15, IntToStr(getZiegel(i,j)));
        end;
    end;
end;

procedure TGUI.roboterZeichnen;
  var x, y: integer;
begin
  x := roboter.getXpos;
  y := roboter.getYpos;
  with IZeichnen.Canvas do
    with roboter do
      case getRichtung of
        osten : dreieckOsten(x*40, y*40, (x+1)*40, (y+1)*40);
        sueden: dreieckSueden(x*40, y*40, (x+1)*40, (y+1)*40);
        westen: dreieckWesten(x*40, y*40, (x+1)*40, (y+1)*40);
        norden: dreieckNorden(x*40, y*40, (x+1)*40, (y+1)*40);
      end;
end;

procedure TGUI.FormCreate(Sender: TObject);
begin
  welt := TWelt.create;
  roboter := TRoboter.create(welt);
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;

procedure TGUI.BInitialisierenClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.initialisieren;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;

procedure TGUI.BLinksClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.linksDrehen;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;

procedure TGUI.BRechtsClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.rechtsDrehen;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;

procedure TGUI.BSchrittClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.schritt;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;


procedure TGUI.BMarkeSetzenClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.markeSetzen;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;

procedure TGUI.BMarkeLoeschenClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.markeLoeschen;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;

procedure TGUI.BZiegelHinlegenClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.ziegelHinlegen;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;

procedure TGUI.BZiegelAufhebenClick(Sender: TObject);
begin
  // Datenmodell aktualisieren
  roboter.ziegelAufheben;
  // Anzeige aktualisieren
  weltZeichnen;
  roboterZeichnen;
end;


end.
